@@ -1,6 +1,3 @@
-/// @ref simd
-/// @file glm/simd/platform.h
-
 #pragma once
 
 ///////////////////////////////////////////////////////////////////////////////////
@@ -42,34 +39,6 @@
 #	define GLM_PLATFORM GLM_PLATFORM_UNKNOWN
 #endif//
 
-// Report platform detection
-#if GLM_MESSAGES == GLM_MESSAGES_ENABLED && !defined(GLM_MESSAGE_PLATFORM_DISPLAYED)
-#	define GLM_MESSAGE_PLATFORM_DISPLAYED
-#	if(GLM_PLATFORM & GLM_PLATFORM_QNXNTO)
-#		pragma message("GLM: QNX platform detected")
-//#	elif(GLM_PLATFORM & GLM_PLATFORM_IOS)
-//#		pragma message("GLM: iOS platform detected")
-#	elif(GLM_PLATFORM & GLM_PLATFORM_APPLE)
-#		pragma message("GLM: Apple platform detected")
-#	elif(GLM_PLATFORM & GLM_PLATFORM_WINCE)
-#		pragma message("GLM: WinCE platform detected")
-#	elif(GLM_PLATFORM & GLM_PLATFORM_WINDOWS)
-#		pragma message("GLM: Windows platform detected")
-#	elif(GLM_PLATFORM & GLM_PLATFORM_CHROME_NACL)
-#		pragma message("GLM: Native Client detected")
-#	elif(GLM_PLATFORM & GLM_PLATFORM_ANDROID)
-#		pragma message("GLM: Android platform detected")
-#	elif(GLM_PLATFORM & GLM_PLATFORM_LINUX)
-#		pragma message("GLM: Linux platform detected")
-#	elif(GLM_PLATFORM & GLM_PLATFORM_UNIX)
-#		pragma message("GLM: UNIX platform detected")
-#	elif(GLM_PLATFORM & GLM_PLATFORM_UNKNOWN)
-#		pragma message("GLM: platform unknown")
-#	else
-#		pragma message("GLM: platform not detected")
-#	endif
-#endif//GLM_MESSAGES
-
 ///////////////////////////////////////////////////////////////////////////////////
 // Compiler
 
@@ -77,58 +46,40 @@
 
 // Intel
 #define GLM_COMPILER_INTEL			0x00100000
-#define GLM_COMPILER_INTEL12		0x00100010
-#define GLM_COMPILER_INTEL12_1		0x00100020
-#define GLM_COMPILER_INTEL13		0x00100030
 #define GLM_COMPILER_INTEL14		0x00100040
 #define GLM_COMPILER_INTEL15		0x00100050
 #define GLM_COMPILER_INTEL16		0x00100060
+#define GLM_COMPILER_INTEL17		0x00100070
 
 // Visual C++ defines
 #define GLM_COMPILER_VC				0x01000000
-#define GLM_COMPILER_VC10			0x01000090
-#define GLM_COMPILER_VC11			0x010000A0
-#define GLM_COMPILER_VC12			0x010000B0
-#define GLM_COMPILER_VC14			0x010000C0
-#define GLM_COMPILER_VC15			0x010000D0
+#define GLM_COMPILER_VC12			0x01000001
+#define GLM_COMPILER_VC14			0x01000002
+#define GLM_COMPILER_VC15			0x01000003
+#define GLM_COMPILER_VC15_3			0x01000004
+#define GLM_COMPILER_VC15_5			0x01000005
+#define GLM_COMPILER_VC15_6			0x01000006
+#define GLM_COMPILER_VC15_7			0x01000007
 
 // GCC defines
 #define GLM_COMPILER_GCC			0x02000000
-#define GLM_COMPILER_GCC44			0x020000B0
-#define GLM_COMPILER_GCC45			0x020000C0
 #define GLM_COMPILER_GCC46			0x020000D0
 #define GLM_COMPILER_GCC47			0x020000E0
 #define GLM_COMPILER_GCC48			0x020000F0
 #define GLM_COMPILER_GCC49			0x02000100
-#define GLM_COMPILER_GCC50			0x02000200
-#define GLM_COMPILER_GCC51			0x02000300
-#define GLM_COMPILER_GCC52			0x02000400
-#define GLM_COMPILER_GCC53			0x02000500
-#define GLM_COMPILER_GCC54			0x02000600
-#define GLM_COMPILER_GCC60			0x02000700
-#define GLM_COMPILER_GCC61			0x02000800
-#define GLM_COMPILER_GCC62			0x02000900
-#define GLM_COMPILER_GCC70			0x02000A00
-#define GLM_COMPILER_GCC71			0x02000B00
-#define GLM_COMPILER_GCC72			0x02000C00
-#define GLM_COMPILER_GCC80			0x02000D00
+#define GLM_COMPILER_GCC5			0x02000200
+#define GLM_COMPILER_GCC6			0x02000300
+#define GLM_COMPILER_GCC7			0x02000400
+#define GLM_COMPILER_GCC8			0x02000500
 
 // CUDA
 #define GLM_COMPILER_CUDA			0x10000000
-#define GLM_COMPILER_CUDA40			0x10000040
-#define GLM_COMPILER_CUDA41			0x10000050
-#define GLM_COMPILER_CUDA42			0x10000060
-#define GLM_COMPILER_CUDA50			0x10000070
-#define GLM_COMPILER_CUDA60			0x10000080
-#define GLM_COMPILER_CUDA65			0x10000090
 #define GLM_COMPILER_CUDA70			0x100000A0
 #define GLM_COMPILER_CUDA75			0x100000B0
 #define GLM_COMPILER_CUDA80			0x100000C0
 
 // Clang
 #define GLM_COMPILER_CLANG			0x20000000
-#define GLM_COMPILER_CLANG32		0x20000030
-#define GLM_COMPILER_CLANG33		0x20000040
 #define GLM_COMPILER_CLANG34		0x20000050
 #define GLM_COMPILER_CLANG35		0x20000060
 #define GLM_COMPILER_CLANG36		0x20000070
@@ -148,20 +99,16 @@
 #	define GLM_COMPILER GLM_COMPILER_UNKNOWN
 
 #elif defined(__INTEL_COMPILER)
-#	if __INTEL_COMPILER == 1200
-#		define GLM_COMPILER GLM_COMPILER_INTEL12
-#	elif __INTEL_COMPILER == 1210
-#		define GLM_COMPILER GLM_COMPILER_INTEL12_1
-#	elif __INTEL_COMPILER == 1300
-#		define GLM_COMPILER GLM_COMPILER_INTEL13
+#	if (__INTEL_COMPILER < 1400)
+#		error "GLM requires ICC 2013 SP1 or newer"
 #	elif __INTEL_COMPILER == 1400
 #		define GLM_COMPILER GLM_COMPILER_INTEL14
 #	elif __INTEL_COMPILER == 1500
 #		define GLM_COMPILER GLM_COMPILER_INTEL15
-#	elif __INTEL_COMPILER >= 1600
+#	elif __INTEL_COMPILER == 1600
 #		define GLM_COMPILER GLM_COMPILER_INTEL16
-#	else
-#		define GLM_COMPILER GLM_COMPILER_INTEL
+#	elif __INTEL_COMPILER >= 1700
+#		define GLM_COMPILER GLM_COMPILER_INTEL17
 #	endif
 
 // CUDA
@@ -169,37 +116,31 @@
 #	if !defined(CUDA_VERSION) && !defined(GLM_FORCE_CUDA)
 #		include <cuda.h>  // make sure version is defined since nvcc does not define it itself!
 #	endif
-#	if CUDA_VERSION < 3000
-#		error "GLM requires CUDA 3.0 or higher"
-#	else
-#		define GLM_COMPILER GLM_COMPILER_CUDA
+#	if CUDA_VERSION < 7000
+#		error "GLM requires CUDA 7.0 or higher"
+#	elif (CUDA_VERSION >= 7000 && CUDA_VERSION < 7500)
+#		define GLM_COMPILER GLM_COMPILER_CUDA70
+#	elif (CUDA_VERSION >= 7500 && CUDA_VERSION < 8000)
+#		define GLM_COMPILER GLM_COMPILER_CUDA75
+#	elif (CUDA_VERSION >= 8000)
+#		define GLM_COMPILER GLM_COMPILER_CUDA80
 #	endif
 
 // Clang
 #elif defined(__clang__)
 #	if defined(__apple_build_version__)
-#		if __clang_major__ == 5 && __clang_minor__ == 0
-#			define GLM_COMPILER GLM_COMPILER_CLANG33
-#		elif __clang_major__ == 5 && __clang_minor__ == 1
-#			define GLM_COMPILER GLM_COMPILER_CLANG34
+#		if (__clang_major__ < 6)
+#			error "GLM requires Clang 3.4 / Apple Clang 6.0 or higher"
 #		elif __clang_major__ == 6 && __clang_minor__ == 0
 #			define GLM_COMPILER GLM_COMPILER_CLANG35
 #		elif __clang_major__ == 6 && __clang_minor__ >= 1
 #			define GLM_COMPILER GLM_COMPILER_CLANG36
 #		elif __clang_major__ >= 7
 #			define GLM_COMPILER GLM_COMPILER_CLANG37
-#		else
-#			define GLM_COMPILER GLM_COMPILER_CLANG
 #		endif
 #	else
-#		if __clang_major__ == 3 && __clang_minor__ == 0
-#			define GLM_COMPILER GLM_COMPILER_CLANG30
-#		elif __clang_major__ == 3 && __clang_minor__ == 1
-#			define GLM_COMPILER GLM_COMPILER_CLANG31
-#		elif __clang_major__ == 3 && __clang_minor__ == 2
-#			define GLM_COMPILER GLM_COMPILER_CLANG32
-#		elif __clang_major__ == 3 && __clang_minor__ == 3
-#			define GLM_COMPILER GLM_COMPILER_CLANG33
+#		if ((__clang_major__ == 3) && (__clang_minor__ < 4)) || (__clang_major__ < 3)
+#			error "GLM requires Clang 3.4 or higher"
 #		elif __clang_major__ == 3 && __clang_minor__ == 4
 #			define GLM_COMPILER GLM_COMPILER_CLANG34
 #		elif __clang_major__ == 3 && __clang_minor__ == 5
@@ -220,39 +161,33 @@
 #			define GLM_COMPILER GLM_COMPILER_CLANG42
 #		elif __clang_major__ >= 4
 #			define GLM_COMPILER GLM_COMPILER_CLANG42
-#		else
-#			define GLM_COMPILER GLM_COMPILER_CLANG
 #		endif
 #	endif
 
 // Visual C++
 #elif defined(_MSC_VER)
-#	if _MSC_VER < 1600
-#		error "GLM requires Visual C++ 10 - 2010 or higher"
-#	elif _MSC_VER == 1600
-#		define GLM_COMPILER GLM_COMPILER_VC11
-#	elif _MSC_VER == 1700
-#		define GLM_COMPILER GLM_COMPILER_VC11
+#	if _MSC_VER < 1800
+#		error "GLM requires Visual C++ 12 - 2013 or higher"
 #	elif _MSC_VER == 1800
 #		define GLM_COMPILER GLM_COMPILER_VC12
 #	elif _MSC_VER == 1900
 #		define GLM_COMPILER GLM_COMPILER_VC14
-#	elif _MSC_VER >= 1910
+#	elif _MSC_VER == 1910
 #		define GLM_COMPILER GLM_COMPILER_VC15
-#	else//_MSC_VER
-#		define GLM_COMPILER GLM_COMPILER_VC
+#	elif _MSC_VER == 1911
+#		define GLM_COMPILER GLM_COMPILER_VC15_3
+#	elif _MSC_VER == 1912
+#		define GLM_COMPILER GLM_COMPILER_VC15_5
+#	elif _MSC_VER == 1913
+#		define GLM_COMPILER GLM_COMPILER_VC15_6
+#	elif _MSC_VER >= 1914
+#		define GLM_COMPILER GLM_COMPILER_VC15_7
 #	endif//_MSC_VER
 
 // G++
 #elif defined(__GNUC__) || defined(__MINGW32__)
-#	if (__GNUC__ == 4) && (__GNUC_MINOR__ == 2)
-#		define GLM_COMPILER (GLM_COMPILER_GCC42)
-#	elif (__GNUC__ == 4) && (__GNUC_MINOR__ == 3)
-#		define GLM_COMPILER (GLM_COMPILER_GCC43)
-#	elif (__GNUC__ == 4) && (__GNUC_MINOR__ == 4)
-#		define GLM_COMPILER (GLM_COMPILER_GCC44)
-#	elif (__GNUC__ == 4) && (__GNUC_MINOR__ == 5)
-#		define GLM_COMPILER (GLM_COMPILER_GCC45)
+#	if ((__GNUC__ == 4) && (__GNUC_MINOR__ < 6)) || (__GNUC__ < 4)
+#		error "GLM requires GCC 4.7 or higher"
 #	elif (__GNUC__ == 4) && (__GNUC_MINOR__ == 6)
 #		define GLM_COMPILER (GLM_COMPILER_GCC46)
 #	elif (__GNUC__ == 4) && (__GNUC_MINOR__ == 7)
@@ -261,32 +196,14 @@
 #		define GLM_COMPILER (GLM_COMPILER_GCC48)
 #	elif (__GNUC__ == 4) && (__GNUC_MINOR__ >= 9)
 #		define GLM_COMPILER (GLM_COMPILER_GCC49)
-#	elif (__GNUC__ == 5) && (__GNUC_MINOR__ == 0)
-#		define GLM_COMPILER (GLM_COMPILER_GCC50)
-#	elif (__GNUC__ == 5) && (__GNUC_MINOR__ == 1)
-#		define GLM_COMPILER (GLM_COMPILER_GCC51)
-#	elif (__GNUC__ == 5) && (__GNUC_MINOR__ == 2)
-#		define GLM_COMPILER (GLM_COMPILER_GCC52)
-#	elif (__GNUC__ == 5) && (__GNUC_MINOR__ == 3)
-#		define GLM_COMPILER (GLM_COMPILER_GCC53)
-#	elif (__GNUC__ == 5) && (__GNUC_MINOR__ >= 4)
-#		define GLM_COMPILER (GLM_COMPILER_GCC54)
-#	elif (__GNUC__ == 6) && (__GNUC_MINOR__ == 0)
-#		define GLM_COMPILER (GLM_COMPILER_GCC60)
-#	elif (__GNUC__ == 6) && (__GNUC_MINOR__ == 1)
-#		define GLM_COMPILER (GLM_COMPILER_GCC61)
-#	elif (__GNUC__ == 6) && (__GNUC_MINOR__ >= 2)
-#		define GLM_COMPILER (GLM_COMPILER_GCC62)
-#	elif (__GNUC__ == 7) && (__GNUC_MINOR__ == 0)
-#		define GLM_COMPILER (GLM_COMPILER_GCC70)
-#	elif (__GNUC__ == 7) && (__GNUC_MINOR__ == 1)
-#		define GLM_COMPILER (GLM_COMPILER_GCC71)
-#	elif (__GNUC__ == 7) && (__GNUC_MINOR__ == 2)
-#		define GLM_COMPILER (GLM_COMPILER_GCC72)
+#	elif (__GNUC__ == 5)
+#		define GLM_COMPILER (GLM_COMPILER_GCC5)
+#	elif (__GNUC__ == 6)
+#		define GLM_COMPILER (GLM_COMPILER_GCC6)
+#	elif (__GNUC__ == 7)
+#		define GLM_COMPILER (GLM_COMPILER_GCC7)
 #	elif (__GNUC__ >= 8)
-#		define GLM_COMPILER (GLM_COMPILER_GCC80)
-#	else
-#		define GLM_COMPILER (GLM_COMPILER_GCC)
+#		define GLM_COMPILER (GLM_COMPILER_GCC8)
 #	endif
 
 #else
@@ -302,45 +219,54 @@
 
 // User defines: GLM_FORCE_PURE GLM_FORCE_SSE2 GLM_FORCE_SSE3 GLM_FORCE_AVX GLM_FORCE_AVX2 GLM_FORCE_AVX2
 
-#define GLM_ARCH_X86_BIT		0x00000001
-#define GLM_ARCH_SSE2_BIT		0x00000002
-#define GLM_ARCH_SSE3_BIT		0x00000004
-#define GLM_ARCH_SSSE3_BIT		0x00000008
-#define GLM_ARCH_SSE41_BIT		0x00000010
-#define GLM_ARCH_SSE42_BIT		0x00000020
-#define GLM_ARCH_AVX_BIT		0x00000040
-#define GLM_ARCH_AVX2_BIT		0x00000080
-#define GLM_ARCH_AVX512_BIT		0x00000100 // Skylake subset
-#define GLM_ARCH_ARM_BIT		0x00000100
-#define GLM_ARCH_NEON_BIT		0x00000200
-#define GLM_ARCH_MIPS_BIT		0x00010000
-#define GLM_ARCH_PPC_BIT		0x01000000
+#define GLM_ARCH_MIPS_BIT	(0x10000000)
+#define GLM_ARCH_PPC_BIT	(0x20000000)
+#define GLM_ARCH_ARM_BIT	(0x40000000)
+#define GLM_ARCH_X86_BIT	(0x80000000)
 
-#define GLM_ARCH_PURE		(0x00000000)
+#define GLM_ARCH_SIMD_BIT	(0x00001000)
+
+#define GLM_ARCH_NEON_BIT	(0x00000001)
+#define GLM_ARCH_SSE_BIT	(0x00000002)
+#define GLM_ARCH_SSE2_BIT	(0x00000004)
+#define GLM_ARCH_SSE3_BIT	(0x00000008)
+#define GLM_ARCH_SSSE3_BIT	(0x00000010)
+#define GLM_ARCH_SSE41_BIT	(0x00000020)
+#define GLM_ARCH_SSE42_BIT	(0x00000040)
+#define GLM_ARCH_AVX_BIT	(0x00000080)
+#define GLM_ARCH_AVX2_BIT	(0x00000100)
+
+#define GLM_ARCH_UNKNOWN	(0)
 #define GLM_ARCH_X86		(GLM_ARCH_X86_BIT)
-#define GLM_ARCH_SSE2		(GLM_ARCH_SSE2_BIT | GLM_ARCH_X86)
+#define GLM_ARCH_SSE		(GLM_ARCH_SSE_BIT | GLM_ARCH_SIMD_BIT | GLM_ARCH_X86)
+#define GLM_ARCH_SSE2		(GLM_ARCH_SSE2_BIT | GLM_ARCH_SSE)
 #define GLM_ARCH_SSE3		(GLM_ARCH_SSE3_BIT | GLM_ARCH_SSE2)
 #define GLM_ARCH_SSSE3		(GLM_ARCH_SSSE3_BIT | GLM_ARCH_SSE3)
 #define GLM_ARCH_SSE41		(GLM_ARCH_SSE41_BIT | GLM_ARCH_SSSE3)
 #define GLM_ARCH_SSE42		(GLM_ARCH_SSE42_BIT | GLM_ARCH_SSE41)
 #define GLM_ARCH_AVX		(GLM_ARCH_AVX_BIT | GLM_ARCH_SSE42)
 #define GLM_ARCH_AVX2		(GLM_ARCH_AVX2_BIT | GLM_ARCH_AVX)
-#define GLM_ARCH_AVX512		(GLM_ARCH_AVX512_BIT | GLM_ARCH_AVX2) // Skylake subset
 #define GLM_ARCH_ARM		(GLM_ARCH_ARM_BIT)
-#define GLM_ARCH_NEON		(GLM_ARCH_NEON_BIT | GLM_ARCH_ARM)
+#define GLM_ARCH_NEON		(GLM_ARCH_NEON_BIT | GLM_ARCH_SIMD_BIT | GLM_ARCH_ARM)
 #define GLM_ARCH_MIPS		(GLM_ARCH_MIPS_BIT)
 #define GLM_ARCH_PPC		(GLM_ARCH_PPC_BIT)
 
-#if defined(GLM_FORCE_PURE)
-#	define GLM_ARCH GLM_ARCH_PURE
-#elif defined(GLM_FORCE_MIPS)
-#	define GLM_ARCH (GLM_ARCH_MIPS)
-#elif defined(GLM_FORCE_PPC)
-#	define GLM_ARCH (GLM_ARCH_PPC)
+#ifdef GLM_FORCE_ARCH_UNKNOWN
+#	define GLM_ARCH GLM_ARCH_UNKNOWN
+#elif defined(GLM_FORCE_PURE) || defined(GLM_FORCE_XYZW_ONLY)
+#	if defined(__x86_64__) || defined(_M_X64) || defined(_M_IX86) || defined(__i386__)
+#		define GLM_ARCH (GLM_ARCH_X86)
+#	elif defined(__arm__ ) || defined(_M_ARM)
+#		define GLM_ARCH (GLM_ARCH_ARM)
+#	elif defined(__powerpc__ ) || defined(_M_PPC)
+#		define GLM_ARCH (GLM_ARCH_PPC)
+#	elif defined(__mips__ )
+#		define GLM_ARCH (GLM_ARCH_MIPS)
+#	else
+#		define GLM_ARCH (GLM_ARCH_UNKNOWN)
+#	endif
 #elif defined(GLM_FORCE_NEON)
 #	define GLM_ARCH (GLM_ARCH_NEON)
-#elif defined(GLM_FORCE_AVX512)
-#	define GLM_ARCH (GLM_ARCH_AVX512)
 #elif defined(GLM_FORCE_AVX2)
 #	define GLM_ARCH (GLM_ARCH_AVX2)
 #elif defined(GLM_FORCE_AVX)
@@ -355,11 +281,10 @@
 #	define GLM_ARCH (GLM_ARCH_SSE3)
 #elif defined(GLM_FORCE_SSE2)
 #	define GLM_ARCH (GLM_ARCH_SSE2)
-#elif (GLM_COMPILER & (GLM_COMPILER_CLANG | GLM_COMPILER_GCC)) || ((GLM_COMPILER & GLM_COMPILER_INTEL) && (GLM_PLATFORM & GLM_PLATFORM_LINUX))
-//	This is Skylake set of instruction set
-#	if defined(__AVX512BW__) && defined(__AVX512F__) && defined(__AVX512CD__) && defined(__AVX512VL__) && defined(__AVX512DQ__)
-#		define GLM_ARCH (GLM_ARCH_AVX512)
-#	elif defined(__AVX2__)
+#elif defined(GLM_FORCE_SSE)
+#	define GLM_ARCH (GLM_ARCH_SSE)
+#else
+#	if defined(__AVX2__)
 #		define GLM_ARCH (GLM_ARCH_AVX2)
 #	elif defined(__AVX__)
 #		define GLM_ARCH (GLM_ARCH_AVX)
@@ -371,50 +296,21 @@
 #		define GLM_ARCH (GLM_ARCH_SSSE3)
 #	elif defined(__SSE3__)
 #		define GLM_ARCH (GLM_ARCH_SSE3)
-#	elif defined(__SSE2__)
+#	elif defined(__SSE2__) || defined(__x86_64__) || defined(_M_X64) || defined(_M_IX86_FP)
 #		define GLM_ARCH (GLM_ARCH_SSE2)
-#	elif defined(__i386__) || defined(__x86_64__)
+#	elif defined(__i386__)
 #		define GLM_ARCH (GLM_ARCH_X86)
 #	elif defined(__ARM_NEON)
 #		define GLM_ARCH (GLM_ARCH_ARM | GLM_ARCH_NEON)
-#	elif defined(__arm__ )
+#	elif defined(__arm__ ) || defined(_M_ARM)
 #		define GLM_ARCH (GLM_ARCH_ARM)
 #	elif defined(__mips__ )
 #		define GLM_ARCH (GLM_ARCH_MIPS)
-#	elif defined(__powerpc__ )
+#	elif defined(__powerpc__ ) || defined(_M_PPC)
 #		define GLM_ARCH (GLM_ARCH_PPC)
 #	else
-#		define GLM_ARCH (GLM_ARCH_PURE)
+#		define GLM_ARCH (GLM_ARCH_UNKNOWN)
 #	endif
-#elif (GLM_COMPILER & GLM_COMPILER_VC) || ((GLM_COMPILER & GLM_COMPILER_INTEL) && (GLM_PLATFORM & GLM_PLATFORM_WINDOWS))
-#	if defined(_M_ARM)
-#		define GLM_ARCH (GLM_ARCH_ARM)
-#	elif defined(__AVX2__)
-#		define GLM_ARCH (GLM_ARCH_AVX2)
-#	elif defined(__AVX__)
-#		define GLM_ARCH (GLM_ARCH_AVX)
-#	elif defined(_M_X64)
-#		define GLM_ARCH (GLM_ARCH_SSE2)
-#	elif defined(_M_IX86_FP)
-#		if _M_IX86_FP >= 2
-#			define GLM_ARCH (GLM_ARCH_SSE2)
-#		else
-#			define GLM_ARCH (GLM_ARCH_PURE)
-#		endif
-#	elif defined(_M_PPC)
-#		define GLM_ARCH (GLM_ARCH_PPC)
-#	else
-#		define GLM_ARCH (GLM_ARCH_PURE)
-#	endif
-#else
-#	define GLM_ARCH GLM_ARCH_PURE
-#endif
-
-// With MinGW-W64, including intrinsic headers before intrin.h will produce some errors. The problem is
-// that windows.h (and maybe other headers) will silently include intrin.h, which of course causes problems.
-// To fix, we just explicitly include intrin.h here.
-#if defined(__MINGW64__) && (GLM_ARCH != GLM_ARCH_PURE)
-#	include <intrin.h>
 #endif
 
 #if GLM_ARCH & GLM_ARCH_AVX2_BIT
@@ -437,16 +333,25 @@
 #endif//GLM_ARCH
 
 #if GLM_ARCH & GLM_ARCH_SSE2_BIT
-	typedef __m128		glm_vec4;
-	typedef __m128i		glm_ivec4;
-	typedef __m128i		glm_uvec4;
+	typedef __m128			glm_f32vec4;
+	typedef __m128i			glm_i32vec4;
+	typedef __m128i			glm_u32vec4;
+	typedef __m128d			glm_f64vec2;
+	typedef __m128i			glm_i64vec2;
+	typedef __m128i			glm_u64vec2;
+
+	typedef glm_f32vec4		glm_vec4;
+	typedef glm_i32vec4		glm_ivec4;
+	typedef glm_u32vec4		glm_uvec4;
+	typedef glm_f64vec2		glm_dvec2;
 #endif
 
 #if GLM_ARCH & GLM_ARCH_AVX_BIT
-	typedef __m256d		glm_dvec4;
+	typedef __m256d			glm_f64vec4;
+	typedef glm_f64vec4		glm_dvec4;
 #endif
 
 #if GLM_ARCH & GLM_ARCH_AVX2_BIT
-	typedef __m256i		glm_i64vec4;
-	typedef __m256i		glm_u64vec4;
+	typedef __m256i			glm_i64vec4;
+	typedef __m256i			glm_u64vec4;
 #endif
